Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
polypandas/__init__.py | 9 | 0 | 0 | 100%
polypandas/exceptions.py | 9 | 0 | 0 | 100%
polypandas/factory.py | 101 | 14 | 0 | 86%
polypandas/io.py | 104 | 24 | 0 | 77%
polypandas/protocols.py | 12 | 4 | 0 | 67%
polypandas/schema.py | 181 | 58 | 0 | 68%
polypandas/testing.py | 74 | 9 | 0 | 88%
Total | 490 | 109 | 0 | 78%

No items found using the specified filter.